Index: runtime/vm/object.h |
diff --git a/runtime/vm/object.h b/runtime/vm/object.h |
index 87fbd6cb11f2ca986907302e46e36f7174f826ce..a41c6ffa7b712f3382da07300c193f462bb4ab49 100644 |
--- a/runtime/vm/object.h |
+++ b/runtime/vm/object.h |
@@ -1556,8 +1556,8 @@ class UnresolvedClass : public Object { |
// Classification of type genericity according to type parameter owners. |
enum Genericity { |
- kAny, // Consider type params of class and functions. |
- kClass, // Consider type params of class only. |
+ kAny, // Consider type params of current class and functions. |
+ kCurrentClass, // Consider type params of current class only. |
kFunctions, // Consider type params of current and parent functions. |
kCurrentFunction, // Consider type params of current function only. |
kParentFunctions // Consider type params of parent functions only. |